nxp-pac

Crates

git

Versions

mcxa577

Flavors

Bufferableen

Enum Bufferableen 

#[repr(u8)]
pub enum Bufferableen { VAL0 = 0, VAL1 = 1, }

Variants



VAL0 = 0

Disabled. For all AHB write accesses (bufferable or nonbufferable), FlexSPI returns AHB Bus Ready after transmitting all data and finishing command.



VAL1 = 1

Enabled. For AHB bufferable write access, FlexSPI returns AHB Bus Ready when the arbitrator grants the AHB command. FlexSPI does not wait for the AHB command to finish.

Implementations

Source

impl Bufferableen

pub const fn from_bits(val: u8) -> Bufferableen

pub const fn to_bits(self) -> u8