#[repr(u8)]pub enum Wmopt2 {
VAL0 = 0,
VAL1 = 1,
}Variants
VAL0 = 0
When writing to an external device, DQS pin is used as write mask. When flash memory is accessed in individual mode, AHB or IP write burst length is not limited.
VAL1 = 1
When writing to an external device, DQS pin is not used as write mask. When flash memory is accessed in individual mode, AHB or IP write burst length is limited. The minimum write burst length should be 4.
Implementations